tiled.queries.Comparison
========================

.. currentmodule:: tiled.queries

.. autoclass:: Comparison

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Comparison.__init__
      ~Comparison.decode
      ~Comparison.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Comparison.operator
      ~Comparison.key
      ~Comparison.value
   
   